︠bf08b260-61b6-45c9-ae78-e057a26a3a8bs︠
def degree(elt, ring=None):
    if ring is None:
        return elt.polynomial().degree()
    if ring is not None:
        try:
            elt = elt.base_extend(ring)
        except TypeError as err:
            print(err)
            print("Define a coercion homomorphism from " + str(elt.parent()) + " to " + str(ring))
        else:
            return elt.polynomial().degree()

K.<t> = CyclotomicField(23)

assert degree(t^13 + 11*t) == 13, "13"
assert degree(3/4*t^6 + 12*t^8+3*t * t^9) == 10, "10"
assert degree(K(1/3)) == 0, "0"
degree(sqrt(2), ring=K)
︡9ac5b607-d5bd-4a21-b366-247e4c7d69cd︡{"stdout":"no base extension defined\nDefine a coercion homomorphism from Symbolic Ring to Cyclotomic Field of order 23 and degree 22\n"}︡{"done":true}︡
︠81b8a1d2-8948-460c-81bd-15b98aff7770s︠
def coefficient(elt,basis_vector):
    higher_powers = elt.list()[degree(basis_vector)+1:]
    if sum([abs(x) for x in higher_powers]):
        raise Exception("Possible non-unique decomposition! "+ str(higher_powers))
    if elt.list()[degree(basis_vector)] == 0:
        return 0
    coeff_elt = elt.list()[degree(basis_vector)]
    highest_coeff_basis_vect = basis_vector.list()[degree(basis_vector)]
    coeff = coeff_elt/highest_coeff_basis_vect
    return coeff

K.<t> = CyclotomicField(5)
basis = [t^2 + 1, t^4 + 2, t^3 + t + 2]
elt = basis[0] + 3/4*basis[1]
assert coefficient(elt, basis[1]) == 3/4, "3/4"
elt = elt - coefficient(elt, basis[1])*basis[1]
assert coefficient(elt, basis[0]) == 1, "1"
assert coefficient(elt, basis[2]) == 0, "0"
︡7938d0f1-5d47-4fd0-93de-8ea6729ab1f1︡{"done":true}︡
︠ee20c16a-7a74-415a-91dd-cea276d079b3s︠
def decompose(elt, basis, integer=True):
    decomposition_vector = [0 for _ in basis]

    while elt != 0:
        for index, basis_elt in enumerate(basis):
            if degree(basis_elt) == degree(elt):
                break
        else:
            raise Exception("Cannot decompose " + str(elt)  + ": no polynomial of matching degree in basis!\n" + str(basis))

        coeff = coefficient(elt, basis_elt)
        if integer:
            assert coeff.is_integer(), str(elt) + " is NOT decomposable over integers!"
        assert decomposition_vector[index] == 0, "Non-unique decomposition!"
        decomposition_vector[index] = coeff
        # print(elt, coeff,basis_elt)
        elt -= coeff*basis_elt
        # print(decomposition_vector)

    return decomposition_vector

K.<t> = NumberField(cyclotomic_polynomial(23))
basis = [t^5 + 2, 13*t -5, 6*t^2+ 2*t + 3]
elt_coords = [-2,3,1]
dot = lambda a,b : sum([x[0]*x[1] for x in zip(a,b)])
elt = dot(basis,elt_coords)
assert decompose(elt, basis) == elt_coords, str(basis)

assert decompose(t^13+11*t, K.ideal((47, t + 20)).integral_basis()) == [-5, 11, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0], "t^13 + 11*t"

try:
    decompose(1/3*t^5 + 5*t^8, K.ideal((47, t + 20)).integral_basis())
except AssertionError as err:
    print(err)
try:
    decompose(3*basis[0] -2*basis[2] - t^4, basis)
except Exception as exc:
    print(exc)

decompose(3*basis[0] -2*basis[2] + basis[1], basis)
︡625cf371-0e55-4c87-9665-aed6e4b2ec6c︡{"stdout":"1/3*t^5 - 220 is NOT decomposable over integers!\n"}︡{"stdout":"Cannot decompose -t^4 - 12*t^2 - 4*t - 6: no polynomial of matching degree in basis!\n[t^5 + 2, 13*t - 5, 6*t^2 + 2*t + 3]\n"}︡{"stdout":"[3, 1, -2]\n"}︡{"done":true}︡
︠1a980520-9c70-440d-97d0-17eb44f11dbfs︠
def matrix_from_ideal(ideal):
    basis = ideal.integral_basis()
    t = ideal.ring().gen()
    shifted_basis = [t*v for v in basis]
    m = matrix([decompose(elt, basis) for elt in shifted_basis])
    return m

K.<t> = CyclotomicField(11)
I = K.ideal(1)
I.gens()
matrix_from_ideal(I)
︡ec26c0fd-cbf0-4e7c-88ed-075bd82489ba︡{"stdout":"(1,)\n"}︡{"stdout":"[ 0  1  0  0  0  0  0  0  0  0]\n[ 0  0  1  0  0  0  0  0  0  0]\n[ 0  0  0  1  0  0  0  0  0  0]\n[ 0  0  0  0  1  0  0  0  0  0]\n[ 0  0  0  0  0  1  0  0  0  0]\n[ 0  0  0  0  0  0  1  0  0  0]\n[ 0  0  0  0  0  0  0  1  0  0]\n[ 0  0  0  0  0  0  0  0  1  0]\n[ 0  0  0  0  0  0  0  0  0  1]\n[-1 -1 -1 -1 -1 -1 -1 -1 -1 -1]\n"}︡{"done":true}︡
︠3f8f0882-2c51-4b9d-b485-8d30a5d22325s︠
show(cyclotomic_polynomial(23))
K.<t> = CyclotomicField(23)
K_IdealClassGrp = K.class_group(proof=False);

## takes ~ 1.5h to compute with proof=True (default)
# K_IdealClassGrp = K.class_group();

I = K_IdealClassGrp.gen();
show(I.gens())

m = matrix_from_ideal((I^1).ideal())
assert m^23 == matrix.identity(22)
assert [QQ(round(x^23,6)) for x in m.eigenvalues()] == 22*[1]
︡527feff5-7e55-46fb-b598-87d3be05f1e5︡{"html":"<div align='center'>$\\displaystyle x^{22} + x^{21} + x^{20} + x^{19} + x^{18} + x^{17} + x^{16} + x^{15} + x^{14} + x^{13} + x^{12} + x^{11} + x^{10} + x^{9} + x^{8} + x^{7} + x^{6} + x^{5} + x^{4} + x^{3} + x^{2} + x + 1$</div>"}︡{"html":"<div align='center'>($\\displaystyle 47$, $\\displaystyle t + 30$, $\\displaystyle t^{2} + 40$, $\\displaystyle t^{3} + 22$, $\\displaystyle t^{4} + 45$, $\\displaystyle t^{5} + 13$, $\\displaystyle t^{6} + 33$, $\\displaystyle t^{7} + 44$, $\\displaystyle t^{8} + 43$, $\\displaystyle t^{9} + 26$, $\\displaystyle t^{10} + 19$, $\\displaystyle t^{11} + 41$, $\\displaystyle t^{12} + 39$, $\\displaystyle t^{13} + 5$, $\\displaystyle t^{14} + 38$, $\\displaystyle t^{15} + 35$, $\\displaystyle t^{16} + 31$, $\\displaystyle t^{17} + 10$, $\\displaystyle t^{18} + 29$, $\\displaystyle t^{19} + 23$, $\\displaystyle t^{20} + 15$, $\\displaystyle t^{21} + 20$)</div>"}︡{"done":true}︡
︠6d8471ff-4535-4d73-9051-107c24191f0as︠
(I^1).ideal().integral_basis()
(I^2).ideal().integral_basis()
(I^3).ideal().integral_basis()
︡d5dd5480-b9dc-49f2-b58a-be982812f058︡{"stdout":"[47, t + 30, t^2 + 40, t^3 + 22, t^4 + 45, t^5 + 13, t^6 + 33, t^7 + 44, t^8 + 43, t^9 + 26, t^10 + 19, t^11 + 41, t^12 + 39, t^13 + 5, t^14 + 38, t^15 + 35, t^16 + 31, t^17 + 10, t^18 + 29, t^19 + 23, t^20 + 15, t^21 + 20]\n"}︡{"stdout":"[47, t + 44, t^2 + 38, t^3 + 20, t^4 + 13, t^5 + 39, t^6 + 23, t^7 + 22, t^8 + 19, t^9 + 10, t^10 + 30, t^11 + 43, t^12 + 35, t^13 + 11, t^14 + 33, t^15 + 5, t^16 + 15, t^17 + 45, t^18 + 41, t^19 + 29, t^20 + 40, t^21 + 26]\n"}︡{"stdout":"[1, t, t^2, t^3, t^4, t^5, t^6, t^7, t^8, t^9, t^10, t^11, t^12, t^13, t^14, t^15, t^16, t^17, t^18, t^19, t^20, t^21]\n"}︡{"done":true}︡
︠25f660a6-b0a7-4e29-ade6-3fece14728b9s︠
show(m)
︡8c05714d-e101-4905-b23e-5b6d8a8c7f1e︡{"html":"<div align='center'>$\\displaystyle \\left(\\begin{array}{rrrrrrrrrrrrrrrrrrrrrr}\n-30 &amp; 47 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 \\\\\n-20 &amp; 30 &amp; 1 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 \\\\\n-26 &amp; 40 &amp; 0 &amp; 1 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 \\\\\n-15 &amp; 22 &amp; 0 &amp; 0 &amp; 1 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 \\\\\n-29 &amp; 45 &amp; 0 &amp; 0 &amp; 0 &amp; 1 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 \\\\\n-9 &amp; 13 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 1 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 \\\\\n-22 &amp; 33 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 1 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 \\\\\n-29 &amp; 44 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 1 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 \\\\\n-28 &amp; 43 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 1 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 \\\\\n-17 &amp; 26 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 1 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 \\\\\n-13 &amp; 19 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 1 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 \\\\\n-27 &amp; 41 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 1 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 \\\\\n-25 &amp; 39 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 1 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 \\\\\n-4 &amp; 5 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 1 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 \\\\\n-25 &amp; 38 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 1 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 \\\\\n-23 &amp; 35 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 1 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 \\\\\n-20 &amp; 31 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 1 &amp; 0 &amp; 0 &amp; 0 &amp; 0 \\\\\n-7 &amp; 10 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 1 &amp; 0 &amp; 0 &amp; 0 \\\\\n-19 &amp; 29 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 1 &amp; 0 &amp; 0 \\\\\n-15 &amp; 23 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 1 &amp; 0 \\\\\n-10 &amp; 15 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 1 \\\\\n0 &amp; 19 &amp; -1 &amp; -1 &amp; -1 &amp; -1 &amp; -1 &amp; -1 &amp; -1 &amp; -1 &amp; -1 &amp; -1 &amp; -1 &amp; -1 &amp; -1 &amp; -1 &amp; -1 &amp; -1 &amp; -1 &amp; -1 &amp; -1 &amp; -1\n\\end{array}\\right)$</div>"}︡{"done":true}︡{"done":true}︡
︠b15a9294-b068-49a1-ae3e-c303598260fas︠
L.<t> = CyclotomicField(29)
L_class_g = L.class_group(proof=False);
L_class_g
L_class_g.gens()
︡d666b45f-c82a-465d-8045-47c28df5400b︡{"stdout":"Class group of order 8 with structure C2 x C2 x C2 of Cyclotomic Field of order 29 and degree 28\n"}︡{"stdout":"(Fractional ideal class (59, t - 26), Fractional ideal class (59, t - 20), Fractional ideal class (59, t - 7))\n"}︡{"done":true}︡
︠cff99cca-f72b-4f19-a916-04aef13b3cees︠
m = matrix_from_ideal(L_class_g.1.ideal())
︡ab4d4299-95b3-416b-816c-f8e65c472b52︡{"done":true}︡
︠37ad4760-044b-40f9-83af-73dcd5f843a7s︠
show(m)
︡6135d5fb-1960-4022-8069-267d9523bc10︡{"html":"<div align='center'>$\\displaystyle \\left(\\begin{array}{rrrrrrrrrrrrrrrrrrrrrrrrrrrr}\n-39 &amp; 59 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 \\\\\n-26 &amp; 39 &amp; 1 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 \\\\\n-9 &amp; 13 &amp; 0 &amp; 1 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 \\\\\n-16 &amp; 24 &amp; 0 &amp; 0 &amp; 1 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 \\\\\n-6 &amp; 8 &amp; 0 &amp; 0 &amp; 0 &amp; 1 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 \\\\\n-28 &amp; 42 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 1 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 \\\\\n-10 &amp; 14 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 1 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 \\\\\n-30 &amp; 44 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 1 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 \\\\\n-36 &amp; 54 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 1 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 \\\\\n-12 &amp; 18 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 1 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 \\\\\n-4 &amp; 6 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 1 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 \\\\\n-2 &amp; 2 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 1 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 \\\\\n-27 &amp; 40 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 1 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 \\\\\n-22 &amp; 33 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 1 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 \\\\\n-8 &amp; 11 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 1 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 \\\\\n-29 &amp; 43 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 1 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 \\\\\n-23 &amp; 34 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 1 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 \\\\\n-21 &amp; 31 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 1 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 \\\\\n-20 &amp; 30 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 1 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 \\\\\n-7 &amp; 10 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 1 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 \\\\\n-16 &amp; 23 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 1 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 \\\\\n-32 &amp; 47 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 1 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 \\\\\n-37 &amp; 55 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 1 &amp; 0 &amp; 0 &amp; 0 &amp; 0 \\\\\n-26 &amp; 38 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 1 &amp; 0 &amp; 0 &amp; 0 \\\\\n-35 &amp; 52 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 1 &amp; 0 &amp; 0 \\\\\n-25 &amp; 37 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 1 &amp; 0 \\\\\n-22 &amp; 32 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 0 &amp; 1 \\\\\n-19 &amp; 49 &amp; -1 &amp; -1 &amp; -1 &amp; -1 &amp; -1 &amp; -1 &amp; -1 &amp; -1 &amp; -1 &amp; -1 &amp; -1 &amp; -1 &amp; -1 &amp; -1 &amp; -1 &amp; -1 &amp; -1 &amp; -1 &amp; -1 &amp; -1 &amp; -1 &amp; -1 &amp; -1 &amp; -1 &amp; -1 &amp; -1\n\\end{array}\\right)$</div>"}︡{"done":true}︡
︠24888f49-cab3-49d4-ab21-253ee537ebd2︠














